==> haskell-chunked-data-0.3.1-297-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-9nchUOlDxbwHqaATnoT2bY
key:                  chunked-data-0.3.1-9nchUOlDxbwHqaATnoT2bY
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  857e95736c576c559abce44ce21b90ff
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-9nchUOlDxbwHqaATnoT2bY
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-5H8NMvQc0Ab8bNH9ZMgAUW

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-Icm4RWQgY72Koiqi7u8seQ
key:                  chunked-data-0.3.1-Icm4RWQgY72Koiqi7u8seQ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  8b34070ce11e6739bf4a5c78e436801d
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-Icm4RWQgY72Koiqi7u8seQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-BWMo7dqC00725tIPRLs4rJ

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
